# iCE40 Boards

The {py:mod}`torii_boards.lattice.ice40` module provides a collection of Lattice iCE40 FPGA development boards, they are based off the Torii {py:class}`ICE40Platform <torii.platform.vendor.lattice.ice40.ICE40Platform>` platform and support the [IceStorm] and [iCECube2] toolchains.

```{eval-rst}
.. autoclass:: torii_boards.lattice.ice40.BlackIceIIPlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.BlackIcePlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.FomuHackerPlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.FomuPVTPlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.ICE40HX1KBlinkEVNPlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.ICE40HX8KBEVNPlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.ICE40UP5KBEVNPlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.ICEBreakerBitsyPlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.ICEBreakerPlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.ICEStickPlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.ICESugarNanoPlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.ICESugarPlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.NandlandGoPlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.TinyFPGABXPlatform
  :members:

.. autoclass:: torii_boards.lattice.ice40.UpduinoV1Platform
  :members:

.. autoclass:: torii_boards.lattice.ice40.UpduinoV2Platform
  :members:

.. autoclass:: torii_boards.lattice.ice40.UpduinoV3Platform
  :members:
```

[IceStorm]: https://github.com/YosysHQ/icestorm
[iCECube2]: https://www.latticesemi.com/iCEcube2
